@@ -8,6 +8,7 @@ test_that("convertInteger", {
   expect_true(identical(convertInteger(NA), as.integer(NA)))
   expect_true(identical(convertInteger(as.integer(NA)), as.integer(NA)))
   expect_true(identical(convertInteger(as.numeric(NA)), as.integer(NA)))
+  expect_true(identical(convertInteger(c(1, NA)), c(1, NA)))
 })
 
 
@@ -20,4 +21,5 @@ test_that("convertIntegers", {
   expect_true(identical(convertIntegers(c(NA, NA)), as.integer(c(NA, NA))))
   expect_true(identical(convertIntegers(as.integer(c(NA, NA))), as.integer(c(NA, NA))))
   expect_true(identical(convertIntegers(as.numeric(c(NA, NA))), as.integer(c(NA, NA))))
+  expect_true(identical(convertIntegers(c(1, NA)), as.integer(c(1, NA))))  
 })
\ No newline at end of file
